@@ -8,10 +8,14 @@ use Locale::TextDomain::OO::Util::Constants;
 use Safe;
 use namespace::autoclean;
 
-our $VERSION = '3.004';
+our $VERSION = '3.005';
+
+sub instance {
+    return __PACKAGE__;
+}
 
 my $safe_already_done;
-if ( $Safe::VERSION < 2.36 ) { ## no critic (MagicNumbers)
+sub patch_safe_module {
     no warnings qw(redefine); ## no critic (NoWarnings)
     # make sure we don't ever double-wrap just in case
     if ( ! $safe_already_done++ ) {
@@ -21,9 +25,7 @@ if ( $Safe::VERSION < 2.36 ) { ## no critic (MagicNumbers)
             $orig_code->(@_);
         };
     }
-}
 
-sub instance {
     return __PACKAGE__;
 }
 
@@ -131,13 +133,13 @@ __END__
 =head1 NAME
 Locale::TextDomain::OO::Util::ExtractHeader - Gettext header extractor
 
-$Id: ExtractHeader.pm 597 2015-06-29 18:27:08Z steffenw $
+$Id: ExtractHeader.pm 600 2015-07-01 04:58:40Z steffenw $
 
 $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/Locale-TextDomain-OO-Util/trunk/lib/Locale/TextDomain/OO/Util/ExtractHeader.pm $
 
 =head1 VERSION
 
-3.004
+3.005
 
 =head1 DESCRIPTION
 
@@ -147,6 +149,10 @@ This module is extracting charset and plural date from gettext header.
 
     use Locale::TextDomain::OO::Util::ExtractHeader;
 
+    my $extractor = Locale::TextDomain::OO::Util::ExtractHeader
+        ->instance
+        ->patch_safe_module;
+    # or
     my $extractor = Locale::TextDomain::OO::Util::ExtractHeader->instance;
 
 =head1 SUBROUTINES/METHODS
@@ -155,6 +161,16 @@ This module is extracting charset and plural date from gettext header.
 
 see SYNOPSIS
 
+=head2 method patch_safe_module
+
+... until your used version of module Safe is monkey patched.
+
+Reason:
+
+Safe will insert nameless variables in the main namespace,
+and Package::Stash croaks.
+See: https://rt.cpan.org/Ticket/Display.html?id=99563
+
 =head2 method extract_header_msgstr
 
     $hash_ref = $extractor->extract_header_msgstr($header_msgstr);
